@@ -1,14 +1,11 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #include "labeledslider.h"
-#include "ksaneoption.h"
 // Qt includes
 
 #include <QLabel>
@@ -17,6 +14,7 @@
 // KDE includes
 
 #include <KPluralHandlingSpinBox>
+#include <Option>
 
 namespace KSaneIface
 {
@@ -25,9 +23,9 @@ LabeledSlider::LabeledSlider(QWidget *parent, const QString &ltext,
     : KSaneOptionWidget(parent, ltext)
 {
     initSlider(min, max, ste);
-}        
+}
 
-LabeledSlider::LabeledSlider(QWidget *parent, KSaneOption *option)
+LabeledSlider::LabeledSlider(QWidget *parent, KSaneCore::Option *option)
     : KSaneOptionWidget(parent, option)
 {
     int maxValue = option->maximumValue().toInt();
@@ -35,42 +33,42 @@ LabeledSlider::LabeledSlider(QWidget *parent, KSaneOption *option)
     int stepValue = option->stepValue().toInt();
 
     initSlider(minValue, maxValue, stepValue);
-    
+
     KLocalizedString unitSuffix;
-    KSaneOption::KSaneOptionUnit unit = option->valueUnit();
+    KSaneCore::Option::OptionUnit unit = option->valueUnit();
     switch (unit) {
 
-    case KSaneOption::UnitPixel:
+    case KSaneCore::Option::UnitPixel:
         unitSuffix = ki18ncp("SpinBox parameter unit", " Pixel", " Pixels");
         break;
-    case KSaneOption::UnitBit:
+    case KSaneCore::Option::UnitBit:
         unitSuffix = ki18ncp("SpinBox parameter unit", " Bit", " Bits");
         break;
-    case KSaneOption::UnitMilliMeter:
+    case KSaneCore::Option::UnitMilliMeter:
         unitSuffix = ki18ncp("SpinBox parameter unit (Millimeter)", " mm", " mm");
         break;
-    case KSaneOption::UnitDPI:
+    case KSaneCore::Option::UnitDPI:
         unitSuffix = ki18ncp("SpinBox parameter unit (Dots Per Inch)", " DPI", " DPI");
         break;
-    case KSaneOption::UnitPercent:
+    case KSaneCore::Option::UnitPercent:
         unitSuffix = ki18ncp("SpinBox parameter unit (Percentage)", " %", " %");
         break;
-    case KSaneOption::UnitMicroSecond:
+    case KSaneCore::Option::UnitMicroSecond:
         unitSuffix = ki18ncp("SpinBox parameter unit (Microseconds)", " µs", " µs");
         break;
-    case KSaneOption::UnitSecond:
+    case KSaneCore::Option::UnitSecond:
         unitSuffix = ki18ncp("SpinBox parameter unit (seconds)", " s", " s");
         break;
-    default: 
+    default:
         unitSuffix = KLocalizedString();
         break;
     }
-    
+
     setSuffix(unitSuffix);
     setLabelText(option->title());
     setToolTip(option->description());
-    connect(this, &LabeledSlider::valueChanged, option, &KSaneOption::setValue);
-    connect(option, &KSaneOption::valueChanged, this, &LabeledSlider::setValue);
+    connect(this, &LabeledSlider::valueChanged, option, &KSaneCore::Option::setValue);
+    connect(option, &KSaneCore::Option::valueChanged, this, &LabeledSlider::setValue);
     int value = option->value().toInt();
     setValue(value);
 }
@@ -111,7 +109,7 @@ void LabeledSlider::initSlider(int minValue, int maxValue, int stepValue)
     m_layout->addWidget(m_slider, 0, 2);
     m_layout->addWidget(m_spinb, 0, 1);
     m_layout->setColumnStretch(1, 0);
-    m_layout->setColumnStretch(2, 50); 
+    m_layout->setColumnStretch(2, 50);
 }
 
 void LabeledSlider::setSuffix(const KLocalizedString &text)
@@ -191,3 +189,5 @@ int LabeledSlider::value() const
 }
 
 }  // NameSpace KSaneIface
+
+#include "moc_labeledslider.cpp"
